function [ret,x0,str,ts,xts]=dcsimnl(t,x,u,flag);
%DCSIMNL	is the M-file description of the SIMULINK system named DCSIMNL.
%	The block-diagram can be displayed by typing: DCSIMNL.
%
%	SYS=DCSIMNL(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DCSIMNL to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DCSIMNL with a FLAG of zero:
%	[SIZES]=DCSIMNL([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[361,321,1004,748])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'T')
set_param(sys,'Min step size', '0.05')
set_param(sys,'Max step size', '0.5')
set_param(sys,'Relative error','1e-6')
set_param(sys,'Return vars',   '')

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[30,18,60,52])

add_block('built-in/To Workspace',[sys,'/','To Workspace  '])
set_param([sys,'/','To Workspace  '],...
		'hide name',0,...
		'mat-name','t',...
		'position',[85,18,120,52])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator']])
set_param([sys,'/',['Signal',13,'Generator']],...
		'hide name',0,...
		'Peak','0.100000',...
		'Peak Range','5.000000',...
		'Freq','0.295000',...
		'Freq Range','5.000000',...
		'Wave','Sqr',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'Generator']],...
		'position',[15,153,60,187])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','3',...
		'position',[535,163,565,197])


%     Subsystem  'angle'.

new_system([sys,'/','angle'])
set_param([sys,'/','angle'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['angle/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['angle/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','angle/x'])
set_param([sys,'/','angle/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','angle'],[90,65;125,65])
set_param([sys,'/','angle'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','angle'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','angle'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','angle'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','angle'],...
		'Mask Entries','T\/-.2\/0.2\/''y-/r-/g-/w:/m*/ro/b+''\/')


%     Finished composite block 'angle'.

set_param([sys,'/','angle'],...
		'position',[595,161,625,199])

add_block('built-in/Gain',[sys,'/',' k 1'])
set_param([sys,'/',' k 1'],...
		'hide name',0,...
		'Gain','6',...
		'Mask Display','P',...
		'position',[220,78,265,122])


%     Subsystem  'Motor'.

new_system([sys,'/','Motor'])
set_param([sys,'/','Motor'],'Location',[280,343,765,588])
open_system([sys,'/','Motor'])

add_block('built-in/Transfer Fcn',[sys,'/','Motor/Load'])
set_param([sys,'/','Motor/Load'],...
		'move name',0,...
		'Numerator','1',...
		'Denominator','[J b]',...
		'position',[215,83,270,137])

add_block('built-in/Gain',[sys,'/','Motor/ k '])
set_param([sys,'/','Motor/ k '],...
		'orientation',2,...
		'hide name',0,...
		'Gain','K',...
		'position',[220,158,265,202])

add_block('built-in/Integrator',[sys,'/','Motor/Int3'])
set_param([sys,'/','Motor/Int3'],...
		'hide name',0,...
		'Initial','.1',...
		'position',[415,82,450,138])

add_block('built-in/Transfer Fcn',[sys,'/','Motor/Armature'])
set_param([sys,'/','Motor/Armature'],...
		'move name',0,...
		'Numerator','K',...
		'Denominator','[L R]',...
		'position',[105,83,165,137])

add_block('built-in/Sum',[sys,'/','Motor/Sum'])
set_param([sys,'/','Motor/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[60,92,80,128])

add_block('built-in/Inport',[sys,'/','Motor/in_1'])
set_param([sys,'/','Motor/in_1'],...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/','Motor/out_1'])
set_param([sys,'/','Motor/out_1'],...
		'position',[470,100,490,120])

add_block('built-in/Dead Zone',[sys,'/','Motor/Dead Zone'])
set_param([sys,'/','Motor/Dead Zone'],...
		'Lower_value','-0.005',...
		'Upper_value','0.01',...
		'position',[320,97,350,123])
add_line([sys,'/','Motor'],[355,110;410,110])
add_line([sys,'/','Motor'],[275,110;315,110])
add_line([sys,'/','Motor'],[170,110;210,110])
add_line([sys,'/','Motor'],[215,180;45,180;55,120])
add_line([sys,'/','Motor'],[85,110;100,110])
add_line([sys,'/','Motor'],[40,100;55,100])
add_line([sys,'/','Motor'],[455,110;465,110])
add_line([sys,'/','Motor'],[380,110;380,180;270,180])
set_param([sys,'/','Motor'],...
		'Mask Display','MOTOR')


%     Finished composite block 'Motor'.

set_param([sys,'/','Motor'],...
		'hide name',0,...
		'position',[345,72,415,128])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'mat-name','uprop',...
		'position',[355,21,420,49])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','eprop',...
		'position',[195,21,260,49])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[130,82,150,118])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'hide name',0,...
		'mat-name','ufuz',...
		'position',[360,256,425,284])

add_block('built-in/Look Up Table',[sys,'/',['Look-Up',13,'Table']])
set_param([sys,'/',['Look-Up',13,'Table']],...
		'hide name',0,...
		'Input_Values','edom',...
		'Output_Values','utab',...
		'Mask Display','Fuzzy',...
		'position',[220,298,270,342])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'hide name',0,...
		'mat-name','efuz',...
		'position',[200,241,265,269])


%     Subsystem  'Motor1'.

new_system([sys,'/','Motor1'])
set_param([sys,'/','Motor1'],'Location',[280,343,765,588])

add_block('built-in/Transfer Fcn',[sys,'/','Motor1/Load'])
set_param([sys,'/','Motor1/Load'],...
		'move name',0,...
		'Numerator','1',...
		'Denominator','[J b]',...
		'position',[215,83,270,137])

add_block('built-in/Gain',[sys,'/','Motor1/ k '])
set_param([sys,'/','Motor1/ k '],...
		'orientation',2,...
		'hide name',0,...
		'Gain','K',...
		'position',[220,158,265,202])

add_block('built-in/Integrator',[sys,'/','Motor1/Int3'])
set_param([sys,'/','Motor1/Int3'],...
		'hide name',0,...
		'Initial','.1',...
		'position',[415,82,450,138])

add_block('built-in/Transfer Fcn',[sys,'/','Motor1/Armature'])
set_param([sys,'/','Motor1/Armature'],...
		'move name',0,...
		'Numerator','K',...
		'Denominator','[L R]',...
		'position',[105,83,165,137])

add_block('built-in/Sum',[sys,'/','Motor1/Sum'])
set_param([sys,'/','Motor1/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[60,92,80,128])

add_block('built-in/Inport',[sys,'/','Motor1/in_1'])
set_param([sys,'/','Motor1/in_1'],...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/','Motor1/out_1'])
set_param([sys,'/','Motor1/out_1'],...
		'position',[470,100,490,120])

add_block('built-in/Dead Zone',[sys,'/','Motor1/Dead Zone'])
set_param([sys,'/','Motor1/Dead Zone'],...
		'Lower_value','-0.005',...
		'Upper_value','0.01',...
		'position',[320,97,350,123])
add_line([sys,'/','Motor1'],[355,110;410,110])
add_line([sys,'/','Motor1'],[275,110;315,110])
add_line([sys,'/','Motor1'],[170,110;210,110])
add_line([sys,'/','Motor1'],[215,180;45,180;55,120])
add_line([sys,'/','Motor1'],[85,110;100,110])
add_line([sys,'/','Motor1'],[40,100;55,100])
add_line([sys,'/','Motor1'],[455,110;465,110])
add_line([sys,'/','Motor1'],[385,110;385,180;270,180])
set_param([sys,'/','Motor1'],...
		'Mask Display','MOTOR')


%     Finished composite block 'Motor1'.

set_param([sys,'/','Motor1'],...
		'hide name',0,...
		'position',[350,292,420,348])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'inputs','2',...
		'position',[340,175,370,210])


%     Subsystem  'control u'.

new_system([sys,'/','control u'])
set_param([sys,'/','control u'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','control u/x'])
set_param([sys,'/','control u/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['control u/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['control u/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','control u'],[90,65;125,65])
set_param([sys,'/','control u'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','control u'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','control u'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','control u'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','control u'],...
		'Mask Entries','T\/-1.5\/1.5\/''y-/r-/g-/w:/m*/ro/b+''\/')


%     Finished composite block 'control u'.

set_param([sys,'/','control u'],...
		'position',[415,176,445,214])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[135,302,155,338])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'hide name',0,...
		'mat-name','yprop',...
		'position',[470,21,535,49])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'hide name',0,...
		'mat-name','yfuz',...
		'position',[530,306,595,334])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'hide name',0,...
		'mat-name','w',...
		'position',[135,186,200,214])
add_line(sys,[65,35;80,35])
add_line(sys,[420,100;440,100;440,155;105,155;105,110;125,110])
add_line(sys,[155,100;165,100;165,35;190,35])
add_line(sys,[155,100;215,100])
add_line(sys,[270,100;340,100])
add_line(sys,[315,100;315,35;350,35])
add_line(sys,[425,320;445,320;445,369;110,369;110,330;130,330])
add_line(sys,[160,320;170,320;170,255;195,255])
add_line(sys,[160,320;215,320])
add_line(sys,[275,320;345,320])
add_line(sys,[320,320;320,270;355,270])
add_line(sys,[440,100;475,100;475,170;530,170])
add_line(sys,[445,320;475,320;475,180;530,180])
add_line(sys,[570,180;590,180])
add_line(sys,[65,170;65,310;130,310])
add_line(sys,[65,170;65,90;125,90])
add_line(sys,[65,280;65,395;505,395;505,190;530,190])
add_line(sys,[320,270;320,200;335,200])
add_line(sys,[315,100;315,185;335,185])
add_line(sys,[375,195;410,195])
add_line(sys,[440,100;440,35;465,35])
add_line(sys,[475,320;525,320])
add_line(sys,[65,200;130,200])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
